import rhinoscriptsyntax as rs

objectIds = rs.SelectedObjects()
if len(objectIds)==0:
    objectIds = rs.GetObjects("Select objects for projection")

if objectIds:
    projectionSrfId = rs.GetObject("Select surface or polysurface to project to", rs.filter.polysurface | rs.filter.surface)
    if projectionSrfId:
        #get parameters
        planes = []
        planes.append("WorldXY") # add World XY
        
        cplanes = rs.NamedCPlanes() # add named CPlanes
        if cplanes:
            for cplane in cplanes:
                planes.append(cplane)
                
        projectionPlane = rs.GetString("Projection plane to use (World or a named Construction Plane)", "WorldXY", planes)
        offset = rs.GetReal("Offset", 0)
    else:
        print "No projection surface selected."
else:
    print "No objects selected."

if objectIds:
    rs.EnableRedraw(True) #disables preview
    
    if projectionSrfId:
        for objectId in objectIds:
            box = rs.BoundingBox(objectId,rs.NamedCPlane(projectionPlane), True) #if CPlane name is not found, falls back on WorldXY
            
            if box:
                bottomRightPt = [0,0,0]
                topLeftPt = [0,0,0]
                bottomLeftPt = [0,0,0]
                for i, point in enumerate(box):
                    if i==1:
                        bottomRightPt = point
                    if i==7:
                        topLeftPt = point
                    if i==3:
                        bottomLeftPt = point
                diagonal = rs.AddLine(topLeftPt, bottomRightPt)
                centroidPt = rs.CurveMidPoint(diagonal)
                rs.DeleteObject(diagonal)
                
                zVector = rs.VectorCreate(bottomLeftPt, topLeftPt)
                zVector = rs.VectorDivide(zVector, 2)
                zVectorU = rs.VectorUnitize(zVector)
                offsetVector = rs.VectorScale(zVectorU,-offset)
                
                bottomCentroidPt = [centroidPt[0] + zVector[0], centroidPt[1] + zVector[1], centroidPt[2] + zVector[2]]
                
                projectedPts = rs.ProjectPointToSurface(bottomCentroidPt, projectionSrfId, zVector)
                
                if projectedPts:
                    nearestProjectedPtId = rs.PointArrayClosestPoint(projectedPts, bottomCentroidPt)
                    destinationPt = projectedPts[nearestProjectedPtId]
                    
                    projectVector = rs.VectorCreate(destinationPt,bottomCentroidPt)
                    if offset != 0:
                        projectVector = rs.VectorAdd(projectVector,offsetVector)
                    rs.MoveObject(objectId, projectVector)
                else:
                    print "Object cannot be projected on surface."
            else:
                print "Bounding-boxes couldn't be created."