# coding: utf-8

import Rhino
import scriptcontext as sc
#from scriptcontext import doc
import System.Drawing
import rhinoscriptsyntax as rs

# adapted from Toni Österlund
# https://discourse.mcneel.com/t/print-layouts-to-pdfs-one-layout-to-one-pdf/39744/69


def createSinglePDF(view, folder):
    pdf = Rhino.FileIO.FilePdf.Create()
    dpi = 300
    inch = 25.4
    width = (view.PageWidth)/inch
    height = (view.PageHeight)/inch
    size = System.Drawing.Size(width*dpi,height*dpi)
    settings = Rhino.Display.ViewCaptureSettings(view, size, dpi)
    settings.RasterMode = False
    pdf.AddPage(settings)
    filename = folder+'/'+view.PageName+'.pdf'
    pdf.Write(filename)
    
def createCombinedPDF(views, filename):
    pdf = Rhino.FileIO.FilePdf.Create()
    dpi = 300
    inch = 25.4
    i = 1
    for view in views:
        print "Printing page " + str(i) + " of " + str(len(views))
        i = i+1
        width = (view.PageWidth)/inch
        height = (view.PageHeight)/inch
        size = System.Drawing.Size(width*dpi,height*dpi)
        settings = Rhino.Display.ViewCaptureSettings(view, size, dpi)
        settings.RasterMode = False
        pdf.AddPage(settings)
    pdf.Write(filename)

layouts = []
layoutNames = []
for i in sc.doc.Views:
    Rhino.Display.RhinoPageView
    if type(i) is Rhino.Display.RhinoPageView:
        layouts.append(i)
        layoutNames.append(i.PageName)
            

            
combine = rs.MessageBox("Combine layouts in one PDF ? Click No to output one PDF per layout.", 3, "Combine layouts ?")
if combine == 6: #YES
    filename = rs.SaveFileName ("Save PDF", "PDF files (*.pdf)|*.pdf||")
    if filename:
        if len(layoutNames)>0:
            layoutNamesSelection = []
            layoutNamesSelection = rs.MultiListBox(layoutNames, "Pick layouts to print in combined PDF", "Layouts")
            if layoutNamesSelection is not None and len(layoutNamesSelection)>0:
                layoutsToPrint = []
                for i in layouts:
                    if (i.PageName in layoutNamesSelection):
                        layoutsToPrint.append(i)
                createCombinedPDF(layoutsToPrint, filename)
                print "Printing finished."
elif combine == 7: #NO
    if len(layoutNames)>0:
        layoutNames = rs.MultiListBox(layoutNames, "Pick layouts to print as single PDF", "Layouts")
    folder = rs.BrowseForFolder("C:\\" )
    if folder: 
        for i in layouts:
            if (i.PageName in layoutNames):
                print "Printing: " + i.PageName + ".pdf"
                createSinglePDF(i,folder)
elif combine == 2: #CANCEL
    exit
